@@ -8,15 +8,27 @@
  * @remark Read the file COPYING
  *
  * @author Graydon Hoare
+ * @author Philippe Elie
  */
 
 #ifndef OP_ABI_H
 #define OP_ABI_H
 
+struct op_abi_entry {
+	char const * name;
+	int offset;		/// offset or size of the named entry
+};
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
+/// return array is terminated by a NULL entry in name field
+struct op_abi_entry const * get_abi(void);
+
+/// return non zero if the abi is little endian
+int op_little_endian(void);
+
 /**
  * Write current abi to file.
  * return 1 on success, 0 on failure
