@@ -2,7 +2,7 @@
  * @file op_config.h
  *
  * Parameters a user may want to change. See
- * also the relevant op_config_2[45].h
+ * also op_config_24.h
  *
  * @remark Copyright 2002 OProfile authors
  * @remark Read the file COPYING
@@ -22,10 +22,15 @@
 #define OP_LOG_FILE OP_BASE_DIR "oprofiled.log"
 #define OP_DUMP_STATUS OP_BASE_DIR "complete_dump"
 
-#define OPD_MAGIC "DAE\n"
-#define OPD_VERSION 0x8
+/* Global directory that stores debug files */
+#ifndef DEBUGDIR
+#define DEBUGDIR "/usr/lib/debug"
+#endif
 
-/** maximum number of profilable kernel modules */
-#define OPD_MAX_MODULES 64
+#define OPD_MAGIC "DAE\n"
+#define OPD_VERSION 0x10
+
+#define OP_MIN_CPU_BUF_SIZE 2048
+#define OP_MAX_CPU_BUF_SIZE 131072
 
 #endif /* OP_CONFIG_H */
