@@ -19,12 +19,14 @@ extern "C" {
 #endif
 
 enum mangle_flags {
-	MANGLE_NONE     = 0,
-	MANGLE_DEP_NAME = (1 << 0),
-	MANGLE_CPU      = (1 << 1),
-	MANGLE_TGID     = (1 << 2),
-	MANGLE_TID      = (1 << 3),
-	MANGLE_KERNEL   = (1 << 4)
+	MANGLE_NONE      = 0,
+	MANGLE_CPU       = (1 << 0),
+	MANGLE_TGID      = (1 << 1),
+	MANGLE_TID       = (1 << 2),
+	MANGLE_KERNEL    = (1 << 3),
+	MANGLE_CALLGRAPH = (1 << 4),
+	MANGLE_ANON      = (1 << 5),
+	MANGLE_CG_ANON   = (1 << 6),
 };
 
 /**
@@ -32,11 +34,11 @@ enum mangle_flags {
  * op_mangle_filename.
  */
 struct mangle_values {
-
 	int flags;
 
 	char const * image_name;
 	char const * dep_name;
+	char const * cg_image_name;
 	char const * event_name;
 	int count;
 	unsigned int unit_mask;
