@@ -89,6 +89,8 @@ struct axis_t {
 	{ "cpu", "specify cpu: or --merge cpu" },
 };
 
+} // anonymous namespace
+
 
 bool profile_classes::matches(profile_classes const & classes)
 {
@@ -129,6 +131,8 @@ bool profile_classes::matches(profile_classes const & classes)
 }
 
 
+namespace {
+
 /// We have more than one axis of classification, tell the user.
 void report_error(profile_classes const & classes, axis_types newaxis)
 {
@@ -253,18 +257,16 @@ opd_header const get_header(profile_class const & pclass,
 
 	citerator it = profile.files.begin();
 	citerator const end = profile.files.end();
-	for ( ; it != end; ++it) {
+	for ( ; it != end; ++it)
 		merge_header(*it, header);
-	}
 
 	list<profile_dep_set>::const_iterator dep_it = profile.deps.begin();
 	list<profile_dep_set>::const_iterator dep_end = profile.deps.end();
 	for ( ; dep_it != dep_end; ++dep_it) {
 		citerator it = dep_it->files.begin();
 		citerator const end = dep_it->files.end();
-		for ( ; it != end; ++it) {
+		for ( ; it != end; ++it)
 			merge_header(*it, header);
-		}
 	}
 
 	return header;
@@ -330,9 +332,8 @@ void identify_classes(profile_classes & classes,
 	vector<profile_class>::iterator end = classes.v.end();
 
 	// only one class, name it after the event
-	if (it == end) {
+	if (it == end)
 		changed[AXIS_EVENT] = true;
-	}
 
 	for (; it != end; ++it) {
 		if (it->ptemplate.event != ptemplate.event
