@@ -11,12 +11,15 @@
 
 #include <unistd.h>
 #include <sys/stat.h>
+#include <fcntl.h>
 #include <dirent.h>
 #include <fnmatch.h>
+#include <utime.h>
 
 #include <cstdio>
 #include <cerrno>
 #include <iostream>
+#include <fstream>
 #include <vector>
 
 #include "op_file.h"
@@ -30,14 +33,41 @@ using namespace std;
 bool copy_file(string const & source, string const & destination)
 {
 	struct stat buf;
-	int status = stat(source.c_str(), &buf);
+	if (stat(source.c_str(), &buf))
+		return false;
 
-	if (status == 0) {
-		/* FIXME: This code should avoid using system() if possible. */
-		string copy_command("cp -a -f " + source + " " + destination);
-		status = system(copy_command.c_str());
+	int fd = open(destination.c_str(), O_RDWR|O_CREAT);
+	if (fd < 0)
+		return false;
+	close(fd);
+
+	mode_t mode = buf.st_mode & ~S_IFMT;
+	if (!(mode & S_IWUSR))
+		mode |= S_IWUSR;
+	if (chmod(destination.c_str(), mode))
+		return false;
+
+	// ignore error here: a simple user can copy a root.root 744 file
+	// but can't chown the copied file to root.
+	chown(destination.c_str(), buf.st_uid, buf.st_gid);
+
+	ifstream in(source.c_str());
+	if (!in)
+		return false;
+	{
+	ofstream out(destination.c_str(), ios::trunc);
+	if (!out)
+		return false;
+	out << in.rdbuf();
 	}
-	return !status;
+
+	struct utimbuf utim;
+	utim.actime = buf.st_atime;
+	utim.modtime = buf.st_mtime;
+	if (utime(destination.c_str(), &utim))
+		return false;
+
+	return true;
 }
 
 
