@@ -14,13 +14,14 @@
 
 #include "config.h"
 
-#include <bfd.h>
-
 #include <vector>
 #include <string>
 #include <list>
+#include <map>
 
+#include "bfd_support.h"
 #include "utility.h"
+#include "cached_value.h"
 #include "op_types.h"
 
 class op_bfd;
@@ -50,6 +51,8 @@ public:
 	asymbol const * symbol() const { return bfd_symbol; }
 	size_t size() const { return symb_size; }
 	void size(size_t s) { symb_size = s; }
+	bool hidden() const { return symb_hidden; }
+	bool weak() const { return symb_weak; }
 
 	/// compare two symbols by their filepos()
 	bool operator<(op_bfd_symbol const & lhs) const;
@@ -69,6 +72,10 @@ private:
 	size_t symb_size;
 	/// the name of the symbol
 	std::string symb_name;
+	/// normally not externally visible symbol
+	bool symb_hidden;
+	/// whether other symbols can override it
+	bool symb_weak;
 };
 
 /**
@@ -145,10 +152,18 @@ public:
 	/** return the relocated PC value for the given file offset */
 	bfd_vma offset_to_pc(bfd_vma offset) const;
 
-	/** return the text section filepos. */
-	unsigned long const get_start_offset() const { return text_offset; }
+	/**
+	 * If passed 0, return the file position of the .text section.
+	 * Otherwise, return the filepos of a section with a matching
+	 * vma.
+	 */
+	unsigned long const get_start_offset(bfd_vma vma = 0) const;
  
-	/// return the image name of the underlying binary image
+	/**
+	 * Return the image name of the underlying binary image. For an
+	 * archive, this returns the path *within* the archive, not the
+	 * full path of the file.
+	 */
 	std::string get_filename() const;
 
 	/// sorted vector by vma of interesting symbol.
@@ -160,49 +175,12 @@ public:
 	size_t bfd_arch_bits_per_address() const;
 
 	/// return true if binary contain some debug information
-	bool has_debug_info() const { return debug_info; }
+	bool has_debug_info() const;
 
 private:
-	/// filename we open
-	std::string filename;
-
-	/// file size in bytes
-	off_t file_size;
-
-	// the bfd object.
-	bfd * ibfd;
-
-	// The following member variables: debug_filename and dbfd are
-	// used to access the optional debugging information file. See
-	// the comment for find_separate_debug_file() for additional
-	// information.
-
-	// corresponding debug file name
-	std::string debug_filename;
-
-	// corresponding debug bfd object.
-	bfd * dbfd;
-
-	// vector of symbol filled by the bfd lib.
-	scoped_array<asymbol*> bfd_syms;
-	// image file such the linux kernel need than all vma are offset
-	// by this value.
-	unsigned long text_offset;
-
-	/// true if at least one section has (flags & SEC_DEBUGGING) != 0
-	bool debug_info;
-
-	/// temporary container for getting symbols
+	/// temporary container type for getting symbols
 	typedef std::list<op_bfd_symbol> symbols_found_t;
 
-	/**
-	 * Helper function for get_symbols.
-	 * Populates bfd_syms and extracts the "interesting_symbol"s.
-	 */
-	void get_symbols_from_file(bfd * ibfd, size_t start,
-				   op_bfd::symbols_found_t & symbols,
-				   bool debug_file);
-
 	/**
 	 * Parse and sort in ascending order all symbols
 	 * in the file pointed to by abfd that reside in
@@ -214,9 +192,17 @@ private:
 	 */
 	void get_symbols(symbols_found_t & symbols);
 
+	/**
+	 * Helper function for get_symbols.
+	 * Populates bfd_syms and extracts the "interesting_symbol"s.
+	 */
+	void get_symbols_from_file(bfd_info & bfd, size_t start,
+				   op_bfd::symbols_found_t & symbols,
+				   bool debug_file);
+
 	/**
 	 * Add the symbols in the binary, applying filtering,
-	 * and handling artificial symbol.
+	 * and handling artificial symbols.
 	 */
 	void add_symbols(symbols_found_t & symbols,
 	                 string_filter const & symbol_filter);
@@ -224,40 +210,44 @@ private:
 	/**
 	 * symbol_size - return the size of a symbol
 	 * @param sym  symbol to get size
-	 * @param next  next symbol in vma roder if any
+	 * @param next  next symbol in vma order if any
 	 */
 	size_t symbol_size(op_bfd_symbol const & sym,
 			   op_bfd_symbol const * next) const;
 
 	/// create an artificial symbol for a symbolless binary
 	op_bfd_symbol const create_artificial_symbol();
+
+        /* Generate symbols using bfd functions for
+	 * the image file associated with the ibfd arg.
+	 */
+	uint process_symtab(bfd_info * bfd, uint start);
+
+	/// filename we open (not including archive path)
+	std::string filename;
+
+	/// path to archive
+	std::string archive_path;
+
+	/// file size in bytes
+	off_t file_size;
+
+	/// corresponding debug file name
+	mutable std::string debug_filename;
+
+	/// true if at least one section has (flags & SEC_DEBUGGING) != 0
+	mutable cached_value<bool> debug_info;
+
+	/// our main bfd object: .bfd may be NULL
+	bfd_info ibfd;
+
+	// corresponding debug bfd object, if one is found
+	mutable bfd_info dbfd;
+
+	typedef std::map<std::string, u32> filepos_map_t;
+	// mapping of section names to filepos in the original binary
+	filepos_map_t filepos_map;
 };
 
-/*
- * find_separate_debug_file - return true if a valid separate debug file found
- * @param ibfd binary file
- * @param dir_in directory holding the binary file
- * @param global_in
- * @param filename path to valid debug file
- *
- * Search order for debug file and use first one found:
- * 1) dir_in directory
- * 2) dir_in/.debug directory
- * 3) global_in/dir_in directory
- *
- * Newer binutils and Linux distributions (e.g. Fedora) allow the
- * creation of debug files that are separate from the binary. The
- * debugging information is stripped out of the binary file, placed in
- * this separate file, and a link to the new file is placed in the
- * binary. The debug files hold the information needed by the debugger
- * (and OProfile) to map machine instructions back to source code.
- */
 
-extern bool
-find_separate_debug_file(bfd * ibfd, 
-                         std::string const & dir_in,
-                         std::string const & global_in,
-                         std::string & filename);
-
-extern bfd * open_bfd(std::string const & file);
 #endif /* !OP_BFD_H */
