@@ -19,9 +19,9 @@ using namespace std;
 
 string_filter::string_filter(string const & include_patterns,
                              string const & exclude_patterns)
+	: include(separate_token(include_patterns, ',')),
+	  exclude(separate_token(exclude_patterns, ','))
 {
-	separate_token(include, include_patterns, ',');
-	separate_token(exclude, exclude_patterns, ',');
 }
 
 
@@ -34,7 +34,7 @@ string_filter::string_filter(vector<string> const & include_patterns,
 
 
 // FIXME: PP reference
-bool string_filter::match(std::string const & str) const
+bool string_filter::match(string const & str) const
 {
 	vector<string>::const_iterator cit;
 	cit = find(exclude.begin(), exclude.end(), str);
