@@ -22,21 +22,9 @@
 #include "op_libiberty.h"
 
 int op_file_readable(char const * file)
-{
-	return !access(file, R_OK);
-}
-
-
-int op_get_fsize(char const * file, off_t * size)
 {
 	struct stat st;
-
-	int err = stat(file, &st);
-	if (err)
-		return err;
-
-	*size = st.st_size;
-	return 0;
+	return !stat(file, &st) && S_ISREG(st.st_mode) && !access(file, R_OK);
 }
 
 
