@@ -65,9 +65,8 @@ string get_annotation_fill()
 		str += string(percent_width, ' ');
 	}
 
-	for (size_t i = 1; i < nr_events; ++i) {
+	for (size_t i = 1; i < nr_events; ++i)
 		str += "  ";
-	}
 
 	str += " :";
 	return str;
@@ -184,8 +183,6 @@ string symbol_annotation(symbol_entry const * symbol)
 
 	string annot = count_str(symbol->sample.counts,
 	                         samples->samples_count());
-	if (annot.empty())
-		return string();
 
 	string const & symname = symbol_names.demangle(symbol->name);
 
@@ -406,9 +403,33 @@ string const source_line_annotation(debug_name_id filename, size_t linenr)
 
 string source_symbol_annotation(debug_name_id filename, size_t linenr)
 {
-	symbol_entry const * symbol = samples->find_symbol(filename, linenr);
+	symbol_collection const symbols = samples->find_symbol(filename, linenr);
 
-	return symbol_annotation(symbol);
+	if (symbols.empty())
+		return string();
+
+	string str = " " + begin_comment;
+
+	count_array_t counts;
+	for (size_t i = 0; i < symbols.size(); ++i) {
+		str += symbol_names.demangle(symbols[i]->name);
+		if (symbols.size() == 1)
+			str += " total: ";
+		else
+			str += " ";
+		str += count_str(symbols[i]->sample.counts,
+		          samples->samples_count());
+		if (symbols.size() != 1)
+			str += ", ";
+
+		counts += symbols[i]->sample.counts;
+	}
+
+	if (symbols.size() > 1)
+		str += "total: " + count_str(counts, samples->samples_count());
+	str += end_comment;
+
+	return str;
 }
 
 
@@ -459,14 +480,13 @@ void do_output_one_file(ostream & out, istream & in, debug_name_id filename,
 		}
 
 	} else {
-		// FIXME : we have no input file : we just outputfooter
-		// so on user can known total nr of samples for this source
-		// later we must add code that iterate through symbol in this
-		// file to output one annotation for each symbol. To do this we
-		// need a select_symbol(filename); in profile_container which
-		// fall back to the implementation in symbol_container
-		// using a lazilly build symbol_map sorted by filename
-		// (necessary functors already exist in symbol_functors.h)
+		// source is not available but we can at least output all the
+		// symbols belonging to this file. This make more visible the
+		// problem of having less samples for a given file than the
+		// sum of all symbols samples for this file due to inlining
+		symbol_collection const symbols = samples->select_symbols(filename);
+		for (size_t i = 0; i < symbols.size(); ++i)
+			out << symbol_annotation(symbols[i]) << endl;
 	}
 
 	if (!header) {
@@ -563,9 +583,8 @@ string const locate_source_file(debug_name_id filename_id)
 	for (; cit != end; ++cit) {
 		string const absfile = op_realpath(*cit + "/" + file);
 
-		if (op_file_readable(absfile)) {
+		if (op_file_readable(absfile))
 			return absfile;
-		}
 	}
 
 	/* We didn't find a relocated absolute file, or a relative file,
@@ -598,14 +617,13 @@ void output_source(path_filter const & filter)
 		// of debug info (eg _init function) so warn only
 		// if the filename is non empty. The case: no debug
 		// info at all has already been checked.
-		if ((!in) && source.length()) {
+		if (!in && source.length()) {
 			cerr << "opannotate (warning): unable to open for "
 			     "reading: " << source << endl;
 		}
 
-		if (source.length()) {
+		if (source.length())
 			output_one_file(in, filenames[i], source);
-		}
 	}
 }
 
@@ -643,9 +661,8 @@ bool annotate_source(list<string> const & images)
 		list<string>::const_iterator const end = images.end();
 
 		for (; it != end; ++it) {
-			if (output_asm(*it)) {
+			if (output_asm(*it))
 				some_output = true;
-			}
 		}
 
 		if (!some_output) {
