@@ -26,6 +26,7 @@ using namespace std;
 profile_classes classes;
 
 namespace options {
+	string archive_path;
 	demangle_type demangle = dmt_normal;
 	string output_dir;
 	vector<string> search_dirs;
@@ -50,7 +51,7 @@ string demangle_option = "normal";
 vector<string> mergespec;
 
 popt::option options_array[] = {
-	popt::option(demangle_option, "demangle", '\0',
+	popt::option(demangle_option, "demangle", 'D',
 		     "demangle GNU C++ symbol names (default normal)",
 	             "none|normal|smart"),
 	popt::option(options::output_dir, "output-dir", 'o',
@@ -68,22 +69,30 @@ popt::option options_array[] = {
 	popt::option(exclude_symbols, "exclude-symbols", 'e',
 		     "exclude these comma separated symbols", "symbols"),
 	popt::option(options::objdump_params, "objdump-params", '\0',
-		     "additionnal params to pass to objdump", "parameters"),
+		     "additional params to pass to objdump", "parameters"),
 	popt::option(options::exclude_dependent, "exclude-dependent", 'x',
 		     "exclude libs, kernel, and module samples for applications"),
 	popt::option(mergespec, "merge", 'm',
 		     "comma separated list", "cpu,tid,tgid,unitmask,all"),
 	popt::option(options::source, "source", 's', "output source"),
 	popt::option(options::assembly, "assembly", 'a', "output assembly"),
+	popt::option(options::threshold_opt, "threshold", 't',
+		     "minimum percentage needed to produce output",
+		     "percent"),
 };
 
 }  // anonymous namespace
 
 
-void handle_options(vector<string> const & non_options)
+void handle_options(options::spec const & spec)
 {
 	using namespace options;
 
+	if (spec.first.size()) {
+		cerr << "differential profiles not allowed" << endl;
+		exit(EXIT_FAILURE);
+	}
+
 	if (!assembly && !source) {
 		cerr <<	"you must specify at least --source or --assembly\n";
 		exit(EXIT_FAILURE);
@@ -101,14 +110,22 @@ void handle_options(vector<string> const & non_options)
 		exit(EXIT_FAILURE);
 	}
 
+	if (assembly && !output_dir.empty()) {
+		cerr << "--output-dir is meaningless with --assembly" << endl;
+		exit(EXIT_FAILURE);
+	}
+
 	options::symbol_filter = string_filter(include_symbols, exclude_symbols);
 
 	options::file_filter = path_filter(include_file, exclude_file);
 
-	profile_spec const spec =
-		profile_spec::create(non_options, options::extra_found_images);
+	profile_spec const pspec =
+		profile_spec::create(spec.common, options::extra_found_images);
 
-	list<string> sample_files = spec.generate_file_list(exclude_dependent, true);
+	list<string> sample_files = pspec.generate_file_list(exclude_dependent, true);
+
+	archive_path = pspec.get_archive_path();
+	cverb << vsfile << "Archive: " << archive_path << endl;
 
 	cverb << vsfile << "Matched sample files: " << sample_files.size()
 	      << endl;
