@@ -118,6 +118,12 @@ void output_cg(FILE * fp, op_bfd const & abfd, profile_t const & cg_db)
 		op_write_u8(fp, GMON_TAG_CG_ARC);
 		op_write_vma(fp, abfd, abfd.offset_to_pc(from + offset));
 		op_write_vma(fp, abfd, abfd.offset_to_pc(to + offset));
+		u32 count = p_it.first.count();
+		if (count != p_it.first.count()) {
+			count = (u32)-1;
+			cerr << "Warning: capping sample count by "
+			     << p_it.first.count() - count << endl;
+		}
 		op_write_u32(fp, p_it.first.count());
 	}
 }
@@ -155,7 +161,7 @@ void output_gprof(op_bfd const & abfd, profile_container const & samples,
 
 	// FIXME: must we skip the flat profile write if histsize == 0 ?
 	// (this can occur with callgraph w/o samples to the binary) but in
-	// this case user must gprof --no-flat-profile whiwh is a bit boring
+	// this case user must gprof --no-flat-profile which is a bit boring
 	// and result *seems* weirds.
 
 	FILE * fp = op_open_file(gmon_filename.c_str(), "w");
@@ -187,7 +193,7 @@ void output_gprof(op_bfd const & abfd, profile_container const & samples,
 		sample_container::samples_iterator end = samples.end(*sit);
 		for (; it != end ; ++it) {
 			u32 pos = (it->second.vma - low_pc) / multiplier;
-			u32 count = it->second.counts[0];
+			count_type count = it->second.counts[0];
 
 			if (pos >= histsize) {
 				cerr << "Bogus histogram bin " << pos
